# Changelog

## 0.1.1

- Re-release for PyPI publishing

## 0.1.0 (2026-03-15)

- Initial release
- Safe enum lookup with `lookup()` and strict validation with `validate()`
- Listing helpers: `values()`, `names()`, `choices()`
- `AutoEnum` subclass for lowercase auto-generated values
- `SerializableEnum` and `SerializableEncoder` for JSON serialization
